OC.L10N.register(
    "core",
    {
    "Please select a file." : "لطفا فایل مورد نظر را انتخاب کنید ",
    "File is too big" : "فایل خیلی بزرگ است",
    "The selected file is not an image." : "فایل انتخاب شده عکس نمی باشد.",
    "The selected file cannot be read." : "فایل انتخاب شده خوانده نمی شود.",
    "The file was uploaded" : "پرونده، بارگذاری شد.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات upload_max_filesize در پرونده php.ini است.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات MAX_FILE_SIZE مشخص شده در فرم HTML است.",
    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شد.",
    "No file was uploaded" : "پرونده‌ای بارگذاری نشد.",
    "Missing a temporary folder" : "پوشه موقت موجود نیست.",
    "Could not write file to disk" : "ناتوانی در نوشتن پرونده روی حافظه.",
    "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد.",
    "Invalid file provided" : "فایل داده‌شده نا معتبر است",
    "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
    "Invalid image" : "عکس نامعتبر",
    "State token does not match" : "State token مطابقت ندارد",
    "Invalid app password" : "کلمه عبور اپلیکیشن اشتباه است.",
    "Could not complete login" : "فرایند ورود شما به سیستم کامل نشد.",
    "State token missing" : "توکن حالت گم شده است.",
    "Your login token is invalid or has expired" : "اطلاعات توکن ورود شما اشتباه یا منقضی است.",
    "Please use original client" : "لطفا از کلاینت اصلی استفاده کنید.",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "این نسخه انجمنی Nextcloud پشتیبانی نمی‌شود و اعلان‌های فشاری محدود هستند.",
    "Login" : "ورود",
    "Unsupported email length (>255)" : "طول ایمیل پشتیبانی نمی‌شود (>255).",
    "Password reset is disabled" : "تنظیم مجدد رمز عبور فعال نیست",
    "Could not reset password because the token is expired" : "رمز عبور بازنشانی نشد زیرا رمز منقضی شده است.",
    "Could not reset password because the token is invalid" : "رمز عبور بازنشانی نشد زیرا رمز نامعتبر است.",
    "Password is too long. Maximum allowed length is 469 characters." : "رمز عبور خیلی طولانی است. حداکثر طول مجاز 469 کاراکتر است.",
    "%s password reset" : "%s رمزعبور تغییر کرد",
    "Password reset" : "تنظیم مجدد رمز عبور",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی دکمه زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی لینک زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Reset your password" : "تنظیم مجدد رمز عبور",
    "The given provider is not available" : "ارائه‌دهنده مشخص‌شده در دسترس نیست.",
    "Task not found" : "وظیفه یافت نشد.",
    "Internal error" : "خطای داخلی.",
    "Not found" : "پیدا نشد.",
    "Bad request" : "درخواست نامعتبر.",
    "Requested task type does not exist" : "نوع وظیفه درخواست شده موجود نیست.",
    "Necessary language model provider is not available" : "ارائه‌دهنده مدل زبان لازم در دسترس نیست.",
    "No text to image provider is available" : "نوشتاری برای ارائه‌دهنده تصویر در دسترس نیست.",
    "Image not found" : "تصویر یافت نشد.",
    "No translation provider available" : "هیچ ارائه‌دهنده ترجمه در دسترس نیست.",
    "Could not detect language" : "امکان تشخیص زبان وجود ندارد.",
    "Unable to translate" : "ناتوان در ترجمه.",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "مرحله تعمیر:",
    "Repair info:" : "اطلاعات تعمیر:",
    "Repair warning:" : "هشدار تعمیر:",
    "Repair error:" : "خطای تعمیر:",
    "Nextcloud Server" : "کارساز نکست‌کلود.",
    "Some of your link shares have been removed" : "برخی از لینک های اشتراک گذاری شده شما حذف شده است.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "به دلیل یک اشکال امنیتی، مجبور شدیم برخی از اشتراک‌گذاری‌های لینک شما را حذف کنیم. برای اطلاعات بیشتر لطفاً لینک را ببینید.",
    "The account limit of this instance is reached." : "محدودیت حساب این نمونه به پایان رسیده است.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "کلید اشتراک خود را در برنامه پشتیبانی وارد کنید تا محدودیت حساب افزایش یابد. این کار همچنین تمام مزایای اضافی را که Nextcloud Enterprise ارائه می‌دهد به شما اعطا می‌کند و برای عملیات در شرکت‌ها بسیار توصیه می‌شود.",
    "Learn more ↗" : "بیشتر بدانید ↗.",
    "Preparing update" : "آماده‌سازی به روز‌ رسانی",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "لطفاً از به‌روزرسان خط فرمان استفاده کنید زیرا به‌روزرسانی از طریق مرورگر در فایل config.php شما غیرفعال شده است.",
    "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
    "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
    "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
    "Updating database schema" : "به روز رسانی طرح پایگاه داده",
    "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
    "Update app \"%s\" from App Store" : "بروزرسانی برنامه \"%s\" از App Store.",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "بررسی اینکه آیا طرح پایگاه داده %s می تواند به روز شود (این ممکن است بسته به اندازه پایگاه داده طولانی باشد)",
    "Updated \"%1$s\" to %2$s" : "بروزرسانی \"%1$s\" به %2$s.",
    "Set log level to debug" : "Set log level to debug",
    "Reset log level" : "Reset log level",
    "Starting code integrity check" : "Starting code integrity check",
    "Finished code integrity check" : "Finished code integrity check",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "برنامه‌های زیر غیرفعال شده‌اند: %s.",
    "Already up to date" : "در حال حاضر بروز است",
    "Windows Command Script" : "اسکریپت فرمان ویندوز.",
    "Electronic book document" : "سند کتاب الکترونیکی.",
    "TrueType Font Collection" : "مجموعه فونت TrueType.",
    "Web Open Font Format" : "فرمت فونت باز وب.",
    "GPX geographic data" : "داده‌های جغرافیایی GPX.",
    "Gzip archive" : "آرشیو Gzip.",
    "Adobe Illustrator document" : "سند Adobe Illustrator.",
    "Java source code" : "کد منبع جاوا.",
    "JavaScript source code" : "کد منبع جاوا اسکریپت.",
    "JSON document" : "سند JSON.",
    "Microsoft Access database" : "پایگاه داده Microsoft Access.",
    "Microsoft OneNote document" : "سند Microsoft OneNote.",
    "Microsoft Word document" : "سند Microsoft Word.",
    "Unknown" : "ناشناخته.",
    "PDF document" : "سند PDF.",
    "PostScript document" : "سند PostScript.",
    "RSS summary" : "خلاصه RSS.",
    "Android package" : "بسته اندروید.",
    "KML geographic data" : "داده‌های جغرافیایی KML.",
    "KML geographic compressed data" : "داده‌های فشرده جغرافیایی KML.",
    "Lotus Word Pro document" : "سند Lotus Word Pro.",
    "Excel spreadsheet" : "صفحه گسترده اکسل.",
    "Excel add-in" : "افزونه اکسل.",
    "Excel 2007 binary spreadsheet" : "صفحه گسترده باینری Excel 2007.",
    "Excel spreadsheet template" : "قالب صفحه گسترده اکسل.",
    "Outlook Message" : "پیام Outlook.",
    "PowerPoint presentation" : "ارائه پاورپوینت.",
    "PowerPoint add-in" : "افزونه پاورپوینت.",
    "PowerPoint presentation template" : "قالب ارائه پاورپوینت.",
    "Word document" : "سند ورد.",
    "ODF formula" : "فرمول ODF.",
    "ODG drawing" : "نقاشی ODG.",
    "ODG drawing (Flat XML)" : "نقاشی ODG (XML مسطح).",
    "ODG template" : "قالب ODG.",
    "ODP presentation" : "ارائه ODP.",
    "ODP presentation (Flat XML)" : "ارائه ODP (XML مسطح).",
    "ODP template" : "قالب ODP.",
    "ODS spreadsheet" : "صفحه گسترده ODS.",
    "ODS spreadsheet (Flat XML)" : "صفحه گسترده ODS (XML مسطح).",
    "ODS template" : "قالب ODS.",
    "ODT document" : "سند ODT.",
    "ODT document (Flat XML)" : "سند ODT (XML مسطح).",
    "ODT template" : "قالب ODT.",
    "PowerPoint 2007 presentation" : "ارائه PowerPoint 2007.",
    "PowerPoint 2007 show" : "نمایش PowerPoint 2007.",
    "PowerPoint 2007 presentation template" : "قالب ارائه PowerPoint 2007.",
    "Excel 2007 spreadsheet" : "صفحه گسترده Excel 2007.",
    "Excel 2007 spreadsheet template" : "قالب صفحه گسترده Excel 2007.",
    "Word 2007 document" : "سند Word 2007.",
    "Word 2007 document template" : "قالب سند Word 2007.",
    "Microsoft Visio document" : "سند Microsoft Visio.",
    "WordPerfect document" : "سند WordPerfect.",
    "7-zip archive" : "آرشیو 7-zip.",
    "Blender scene" : "صحنه Blender.",
    "Bzip2 archive" : "آرشیو Bzip2.",
    "Debian package" : "بسته Debian.",
    "FictionBook document" : "سند FictionBook.",
    "Unknown font" : "فونت ناشناخته.",
    "Krita document" : "سند Krita.",
    "Mobipocket e-book" : "کتاب الکترونیکی Mobipocket.",
    "Windows Installer package" : "بسته نصب کننده ویندوز.",
    "Perl script" : "اسکریپت Perl.",
    "PHP script" : "اسکریپت PHP.",
    "Tar archive" : "آرشیو Tar.",
    "XML document" : "سند XML.",
    "YAML document" : "سند YAML.",
    "Zip archive" : "آرشیو Zip.",
    "Zstandard archive" : "آرشیو Zstandard.",
    "AAC audio" : "صوت AAC.",
    "FLAC audio" : "صوت FLAC.",
    "MPEG-4 audio" : "صوت MPEG-4.",
    "MP3 audio" : "صوت MP3.",
    "Ogg audio" : "صوت Ogg.",
    "RIFF/WAVe standard Audio" : "صوت استاندارد RIFF/WAVe.",
    "WebM audio" : "صوت WebM.",
    "MP3 ShoutCast playlist" : "لیست پخش MP3 ShoutCast.",
    "Windows BMP image" : "تصویر Windows BMP.",
    "Better Portable Graphics image" : "تصویر گرافیکی قابل حمل بهتر.",
    "EMF image" : "تصویر EMF.",
    "GIF image" : "تصویر GIF.",
    "HEIC image" : "تصویر HEIC.",
    "HEIF image" : "تصویر HEIF.",
    "JPEG-2000 JP2 image" : "تصویر JPEG-2000 JP2.",
    "JPEG image" : "تصویر JPEG.",
    "PNG image" : "تصویر PNG.",
    "SVG image" : "تصویر SVG.",
    "Truevision Targa image" : "تصویر Truevision Targa.",
    "TIFF image" : "تصویر TIFF.",
    "WebP image" : "تصویر WebP.",
    "Digital raw image" : "تصویر خام دیجیتال.",
    "Windows Icon" : "آیکون ویندوز.",
    "Email message" : "پیام ایمیل.",
    "VCS/ICS calendar" : "تقویم VCS/ICS.",
    "CSS stylesheet" : "شیوه نامه CSS.",
    "CSV document" : "سند CSV.",
    "HTML document" : "سند HTML.",
    "Markdown document" : "سند Markdown.",
    "Org-mode file" : "فایل Org-mode.",
    "Plain text document" : "سند متن ساده.",
    "Rich Text document" : "سند Rich Text.",
    "Electronic business card" : "کارت ویزیت الکترونیکی.",
    "C++ source code" : "کد منبع C++.",
    "LDIF address book" : "دفترچه آدرس LDIF.",
    "NFO document" : "سند NFO.",
    "PHP source" : "منبع PHP.",
    "Python script" : "اسکریپت پایتون.",
    "ReStructuredText document" : "سند ReStructuredText.",
    "3GPP multimedia file" : "فایل چندرسانه‌ای 3GPP.",
    "MPEG video" : "ویدیوی MPEG.",
    "DV video" : "ویدیوی DV.",
    "MPEG-2 transport stream" : "جریان حمل و نقل MPEG-2.",
    "MPEG-4 video" : "ویدیوی MPEG-4.",
    "Ogg video" : "ویدیوی Ogg.",
    "QuickTime video" : "ویدیوی QuickTime.",
    "WebM video" : "ویدیوی WebM.",
    "Flash video" : "ویدیوی Flash.",
    "Matroska video" : "ویدیوی Matroska.",
    "Windows Media video" : "ویدیوی Windows Media.",
    "AVI video" : "ویدیوی AVI.",
    "unknown text" : "متن نامعلوم",
    "Hello world!" : "سلام دنیا!",
    "sunny" : "آفتابی",
    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
    "Hello {name}" : "سلام {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>این نتایج جستجوی شماست <script>alert(1)</script> </strong>",
    "new" : "جدید",
    "_download %n file_::_download %n files_" : ["دانلود %n فایل","دانلود %n فایل"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "به روز رسانی در حال انجام است، این صفحه ممکن است روند در برخی از محیط ها را قطع کند.",
    "Update to {version}" : "بروزرسانی به  {version}",
    "An error occurred." : "یک خطا رخ‌داده است.",
    "Please reload the page." : "لطفا صفحه را دوباره بارگیری کنید.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "به روزرسانی ناموفق بود. برای اطلاعات بیشتر <a href=\"{url}\">فروم ما را بررسی کنید</a>",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
    "Continue to {productName}" : "به {productName} ادامه دهید.",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید.","به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید."],
    "Applications menu" : "منو برنامه‌ها.",
    "Apps" : "  برنامه ها",
    "More apps" : "برنامه های بیشتر",
    "_{count} notification_::_{count} notifications_" : ["{count} اعلان.","{count} اعلان."],
    "No" : "نه",
    "Yes" : "بله",
    "The remote URL must include the user." : "آدرس URL راه دور باید شامل کاربر باشد.",
    "Invalid remote URL." : "آدرس URL راه دور نامعتبر است.",
    "Failed to add the public link to your Nextcloud" : "خطا در افزودن آدرس عمومی به نکست‌کلود شما.",
    "Federated user" : "کاربر فدرال.",
    "user@your-nextcloud.org" : "user@your-nextcloud.org.",
    "Create share" : "ساختن اشتراک.",
    "Please copy the link manually:" : "لطفاً لینک را به صورت دستی کپی کنید:",
    "Custom date range" : "بازه تاریخی سفارشی.",
    "Pick start date" : "انتخاب تاریخ شروع.",
    "Pick end date" : "انتخاب تاریخ پایان.",
    "Search in date range" : "جستجو در بازه تاریخی.",
    "Search in current app" : "جستجو در برنامه فعلی.",
    "Clear search" : "پاک کردن جستجو.",
    "Search everywhere" : "جستجو در هر کجا.",
    "Searching …" : "جستجوکردن …",
    "Start typing to search" : "برای جستجو شروع به تایپ کنید.",
    "No matching results" : "نتیجه مطابق یافت نشد.",
    "Today" : "امروز.",
    "Last 7 days" : "۷ روز گذشته.",
    "Last 30 days" : "۳۰ روز گذشته.",
    "This year" : "امسال.",
    "Last year" : "پارسال.",
    "Unified search" : "جستجوی یکپارچه.",
    "Search apps, files, tags, messages" : "جستجوی برنامه‌ها، پرونده‌ها، برچسب‌ها، پیام‌ها.",
    "Places" : "مکان ها.",
    "Date" : "تاریخ.",
    "Search people" : "جستجوی افراد.",
    "People" : "مردم.",
    "Filter in current view" : "فیلتر در نمای فعلی.",
    "Results" : "نتایج.",
    "Load more results" : "بار کردن نتایج بیشتر.",
    "Search in" : "جستجو در.",
    "Log in" : "ورود",
    "Logging in …" : "ورود به سیستم ...",
    "Log in to {productName}" : "ورود به {productName}.",
    "Wrong login or password." : "نام کاربری یا رمز عبور اشتباه است.",
    "This account is disabled" : "این حساب کاربری غیرفعال است.",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
    "Account name or email" : "نام کاربری یا آدرس ایمیل.",
    "Account name" : "نام حساب.",
    "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
    "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
    "Session error" : "خطای جلسه.",
    "It appears your session token has expired, please refresh the page and try again." : "به نظر می‌رسد توکن جلسه شما منقضی شده است، لطفاً صفحه را بازخوانی کرده و دوباره امتحان کنید.",
    "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
    "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
    "Password" : "گذرواژه",
    "Log in with a device" : "ورود با یک دستگاه.",
    "Login or email" : "نام کاربری یا ایمیل.",
    "Your account is not setup for passwordless login." : "حساب شما برای ورود بدون رمز عبور تنظیم نشده است.",
    "Your connection is not secure" : "اتصال شما امن نیست.",
    "Passwordless authentication is only available over a secure connection." : "احراز هویت بدون رمز عبور فقط از طریق اتصال امن در دسترس است.",
    "Browser not supported" : "مرورگر پشتیبانی نمی‌شود.",
    "Passwordless authentication is not supported in your browser." : "احراز هویت بدون رمز عبور در مرورگر شما پشتیبانی نمی‌شود.",
    "Reset password" : "تنظیم مجدد رمز عبور",
    "Back to login" : "بازگشت به ورود.",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "اگر این حساب کاربری وجود داشته باشد، پیامی برای بازنشانی رمز عبور به آدرس ایمیل آن ارسال شده است. اگر آن را دریافت نکردید، آدرس ایمیل و/یا نام کاربری خود را بررسی کنید، پوشه‌های اسپم/جفیت خود را بررسی کنید یا از مدیر محلی خود کمک بخواهید.",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "Password cannot be changed. Please contact your administrator." : "رمز عبور قابل تغییر نیست. لطفاً با مدیر سیستم تماس بگیرید.",
    "New password" : "گذرواژه جدید",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "فایل‌های شما رمزگذاری شده‌اند. پس از بازنشانی رمز عبور شما، هیچ راهی برای بازیابی اطلاعات شما وجود نخواهد داشت. اگر مطمئن نیستید که چه کاری باید انجام دهید، لطفاً قبل از ادامه با مدیر خود تماس بگیرید. آیا واقعاً می‌خواهید ادامه دهید؟",
    "I know what I'm doing" : "اطلاع از انجام این کار دارم",
    "Resetting password" : "در حال ریست کردن کلمه عبور... .",
    "Schedule work & meetings, synced with all your devices." : "زمان‌بندی کار و جلسات، همگام‌سازی‌شده با تمام دستگاه‌های شما.",
    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها، مخاطبین و تقویم یکپارچه شده است.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "گفتگو، تماس‌های ویدیویی، اشتراک‌گذاری صفحه، جلسات آنلاین و وب‌کنفرانس – در مرورگر شما و با برنامه‌های موبایل.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "اسناد، صفحات گسترده و ارائه‌های مشترک، بر اساس Collabora Online ساخته شده‌اند.",
    "Distraction free note taking app." : "برنامه یادداشت‌برداری بدون حواس‌پرتی.",
    "Recommended apps" : "برنامه‌های پیشنهادی.",
    "Loading apps …" : "در حال بارگذاری برنامه ها... .",
    "Could not fetch list of apps from the App Store." : "امکان دریافت لیست برنامه ها از App Store وجود نداشت.",
    "App download or installation failed" : "دانلود یا نصب برنامه ناموفق بود.",
    "Cannot install this app because it is not compatible" : "نمی توان این برنامه را نصب کرد زیرا سازگار نیست.",
    "Cannot install this app" : "نمی توان این برنامه را نصب کرد.",
    "Skip" : "پرش.",
    "Installing apps …" : "در حال نصب برنامه.",
    "Install recommended apps" : "نصب کاره‌های پیشنهادی.",
    "Avatar of {displayName}" : "نمایه {displayName}.",
    "Settings menu" : "فهرست تنظیمات.",
    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
    "Looking for {term} …" : "به دنبال {term} …",
    "Search contacts" : "جستجوی مخاطبین.",
    "Reset search" : "بازنشانی جستجو.",
    "Search contacts …" : "جستجو مخاطبین ...",
    "Could not load your contacts" : "امکان بارگذاری مخاطبین شما وجود نداشت.",
    "No contacts found" : "مخاطبین یافت نشد",
    "Show all contacts" : "نمایش تمام مخاطبین.",
    "Install the Contacts app" : "برنامه مخاطبین را نصب کنید.",
    "Search" : "جست‌و‌جو",
    "No results for {query}" : "هیچ نتیجه‌ای برای {query} یافت نشد.",
    "Press Enter to start searching" : "برای شروع جستجو Enter را فشار دهید.",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["لطفا برای جستجو حداقل %n کاراکتر یا بیشتر وارد کنید.","لطفا برای جستجو حداقل %n کاراکتر یا بیشتر وارد کنید."],
    "An error occurred while searching for {type}" : "خطایی در هنگام جستجو برای {type} رخ داد.",
    "Search starts once you start typing and results may be reached with the arrow keys" : "جستجو با شروع تایپ آغاز می‌شود و نتایج را می‌توان با کلیدهای جهت‌نما مشاهده کرد.",
    "Search for {name} only" : "فقط {name} را جستجو کنید.",
    "Loading more results …" : "در حال بارگذاری نتایج بیشتر ... .",
    "Forgot password?" : "رمز فراموش شده؟",
    "Back to login form" : "بازگشت به فرم ورود.",
    "Back" : "بازگشت.",
    "Login form is disabled." : "فرم ورود غیرفعال است.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "فرم ورود Nextcloud غیرفعال است. در صورت امکان از گزینه ورود دیگری استفاده کنید یا با مدیریت خود تماس بگیرید.",
    "More actions" : "اقدامات بیشتر.",
    "Password is too weak" : "رمز عبور بسیار ضعیف است.",
    "Password is weak" : "رمز عبور ضعیف است.",
    "Password is average" : "رمز عبور متوسط است.",
    "Password is strong" : "رمز عبور قوی است.",
    "Password is very strong" : "رمز عبور بسیار قوی است.",
    "Password is extremely strong" : "رمز عبور فوق‌العاده قوی است.",
    "Unknown password strength" : "قدرت رمز عبور ناشناخته.",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "پوشه داده و فایل‌های شما احتمالاً از اینترنت قابل دسترسی هستند زیرا فایل <code>.htaccess</code> کار نمی‌کند.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "برای اطلاعات بیشتر در مورد نحوه پیکربندی صحیح سرور خود، لطفاً {linkStart}مستندات را ببینید{linkEnd}.",
    "Autoconfig file detected" : "فایل تنظیم خودکار شناسایی شد.",
    "The setup form below is pre-filled with the values from the config file." : "فرم تنظیمات زیر با مقادیر موجود در فایل پیکربندی از قبل پر شده است.",
    "Security warning" : "اخطار امنیتی",
    "Create administration account" : "ایجاد حساب کاربری مدیریت.",
    "Administration account name" : "نام حساب کاربری مدیریت.",
    "Administration account password" : "رمز عبور حساب کاربری مدیریت.",
    "Storage & database" : "انبارش و پایگاه داده",
    "Data folder" : "پوشه اطلاعاتی",
    "Database configuration" : "پیکربندی پایگاه داده.",
    "Only {firstAndOnlyDatabase} is available." : "تنها {firstAndOnlyDatabase} در دسترس است.",
    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
    "Performance warning" : "اخطار کارایی",
    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite فقط باید برای نمونه‌های حداقل و توسعه استفاده شود. برای تولید، یک پایگاه داده پشتیبانی دیگر توصیه می‌کنیم.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "اگر از کلاینت‌ها برای همگام‌سازی فایل استفاده می‌کنید، استفاده از SQLite بسیار توصیه نمی‌شود.",
    "Database user" : "شناسه پایگاه داده.",
    "Database password" : "پسورد پایگاه داده",
    "Database name" : "نام پایگاه داده",
    "Database tablespace" : "جدول پایگاه داده",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
    "Database host" : "هاست پایگاه داده",
    "localhost" : "لوکال‌هاست",
    "Installing …" : "درحال نصب...",
    "Install" : "نصب",
    "Need help?" : "کمک لازم دارید ؟",
    "See the documentation" : "مشاهده‌ی مستندات",
    "{name} version {version} and above" : "{name} نسخه {version} و بالاتر",
    "This browser is not supported" : "این مرورگر پشتیبانی نمی‌شود",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "مرورگر شما پشتیبانی نمی‌شود. لطفاً به نسخه جدیدتر یا نسخه پشتیبانی‌شده ارتقا دهید.",
    "Continue with this unsupported browser" : "با این مرورگر پشتیبانی‌نشده ادامه دهید",
    "Supported versions" : "نسخه‌های پشتیبانی شده",
    "Search {types} …" : "جستجوی {types}...",
    "Choose {file}" : "انتخاب {file}",
    "Choose" : "انتخاب کردن",
    "Copy to {target}" : "رونوشت به {target}",
    "Copy" : "کپی",
    "Move to {target}" : "جابجایی به {target}",
    "Move" : "انتقال",
    "OK" : "تایید",
    "read-only" : "فقط-خواندنی",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count}  تضاد در فایل","{count}  تضاد در فایل"],
    "One file conflict" : "یک فایل متضاد",
    "New Files" : "فایل های جدید",
    "Already existing files" : "فایل های موجود در حال حاضر ",
    "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
    "If you select both versions, the copied file will have a number added to its name." : "اگر هر دو نسخه را انتخاب کنید، فایل کپی شده یک شماره به نام آن اضافه خواهد شد.",
    "Cancel" : "منصرف شدن",
    "Continue" : "ادامه",
    "(all selected)" : "(همه انتخاب شده اند)",
    "({count} selected)" : "({count} انتخاب شده)",
    "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
    "Saving …" : "ذخیره کردن …",
    "seconds ago" : "ثانیه‌ها پیش",
    "Connection to server lost" : "اتصال به سرور از دست رفته است",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
    "Add to a project" : "افزودن به یک پروژه",
    "Show details" : "نمایش جزئیات",
    "Hide details" : "مخفی کردن جزئیات",
    "Rename project" : "تغییر نام پروژه",
    "Failed to rename the project" : "تغییر نام پروژه ناموفق بود",
    "Failed to create a project" : "ایجاد پروژه ناموفق بود",
    "Failed to add the item to the project" : "افزودن مورد به پروژه ناموفق بود",
    "Connect items to a project to make them easier to find" : "موارد را به یک پروژه متصل کنید تا یافتن آنها آسان‌تر شود",
    "Type to search for existing projects" : "برای جستجوی پروژه‌های موجود تایپ کنید",
    "New in" : "جدید در",
    "View changelog" : "مشاهده تغییرات",
    "No action available" : "هیچ عملی قابل انجام نیست",
    "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
    "Close \"{dialogTitle}\" dialog" : "بستن گفتگوی «{dialogTitle}»",
    "Email length is at max (255)" : "طول ایمیل حداکثر (۲۵۵) است",
    "Clipboard not available, please copy manually" : "کلیپ بورد در دسترس نیست، لطفا به صورت دستی کپی کنید",
    "Personal" : "شخصی",
    "Accounts" : "حساب‌ها",
    "Admin" : "مدیر",
    "Help" : "راه‌نما",
    "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
    "Back to %s" : "بازگشت به %s",
    "Page not found" : "صفحه یافت نشد",
    "The page could not be found on the server or you may not be allowed to view it." : "صفحه در سرور یافت نشد یا ممکن است شما اجازه مشاهده آن را نداشته باشید.",
    "Too many requests" : "درخواست‌های زیاد",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "درخواست‌های زیادی از شبکه شما وجود داشت. بعداً دوباره امتحان کنید یا در صورت بروز خطا با مدیر خود تماس بگیرید.",
    "Error" : "خطا",
    "Internal Server Error" : "خطای داخلی سرور",
    "The server was unable to complete your request." : "سرور قادر به تکمیل درخواست شما نبود.",
    "If this happens again, please send the technical details below to the server administrator." : "اگر این اتفاق دوباره افتاد، لطفا جزئیات فنی زیر را به مدیر سرور ارسال کنید.",
    "More details can be found in the server log." : "جزئیات بیشتر در لاگ سرور قابل مشاهده خواهد بود.",
    "For more details see the documentation ↗." : "برای جزئیات بیشتر به مستندات ↗ مراجعه کنید.",
    "Technical details" : "جزئیات فنی",
    "Remote Address: %s" : "آدرس راه‌دور: %s",
    "Request ID: %s" : "ID درخواست: %s",
    "Type: %s" : "نوع: %s",
    "Code: %s" : "کد: %s",
    "Message: %s" : "پیام: %s",
    "File: %s" : "فایل : %s",
    "Line: %s" : "خط: %s",
    "Trace" : "ردیابی",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "به نظر می رسد شما در حال تلاش برای نصب مجدد Nextcloud خود هستید. با این حال فایل CAN_INSTALL از دایرکتوری تنظیمات شما گم شده است. لطفاً فایل CAN_INSTALL را در پوشه تنظیمات خود ایجاد کنید تا ادامه دهید.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "فایل CAN_INSTALL از پوشه تنظیمات قابل حذف نیست. لطفاً این فایل را به صورت دستی حذف کنید.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "این برنامه برای عملکرد صحیح به جاوا اسکریپت نیاز دارد. لطفاً {linkstart}جاوا اسکریپت را فعال کنید{linkend} و صفحه را بارگذاری مجدد کنید.",
    "Skip to main content" : "پرش به محتوای اصلی",
    "Skip to navigation of app" : "پرش به ناوبری برنامه",
    "Go to %s" : "برو به %s",
    "Get your own free account" : "حساب کاربری رایگان خود را دریافت کنید",
    "Connect to your account" : "به حساب کاربری خود متصل شوید",
    "Please log in before granting %1$s access to your %2$s account." : "لطفاً قبل از اعطای دسترسی %1$s به حساب %2$s خود وارد شوید.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "اگر قصد راه‌اندازی دستگاه یا برنامه جدیدی را ندارید، شخصی در تلاش است تا شما را فریب دهد تا به داده‌هایتان دسترسی پیدا کند. در این صورت ادامه ندهید و به جای آن با مدیر سیستم خود تماس بگیرید.",
    "App password" : "گذرواژه برنامه",
    "Grant access" : " مجوز اعطا دسترسی",
    "Alternative log in using app password" : "ورود جایگزین با استفاده از گذرواژه برنامه",
    "Account access" : "دسترسی به حساب",
    "Currently logged in as %1$s (%2$s)." : "در حال حاضر به عنوان %1$s (%2$s) وارد شده‌اید.",
    "You are about to grant %1$s access to your %2$s account." : "شما در حال اعطای دسترسی %1$s به حساب %2$s خود هستید.",
    "Account connected" : "حساب کاربری متصل شد",
    "Your client should now be connected!" : "اکنون مشتری شما باید متصل شده باشد!",
    "You can close this window." : "می‌توانید این پنجره را ببندید.",
    "Previous" : "قبلی",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong or expired. Please try again or request a new one." : "رمز عبور اشتباه است یا منقضی شده است. لطفا دوباره تلاش کنید یا رمز عبور جدیدی درخواست دهید.",
    "Please type in your email address to request a temporary password" : "لطفاً آدرس ایمیل خود را برای درخواست گذرواژه موقت وارد کنید",
    "Email address" : "آدرس ایمیل",
    "Password sent!" : "گذرواژه ارسال شد!",
    "You are not authorized to request a password for this share" : "شما مجاز به درخواست گذرواژه برای این اشتراک نیستید",
    "Two-factor authentication" : "احراز هویت دو مرحله‌ای",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "امنیت پیشرفته برای حساب شما فعال شده است. عامل دوم را برای احراز هویت انتخاب کنید:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "حداقل یکی از روش‌های احراز هویت دو عاملی فعال شما بارگذاری نشد. لطفاً با مدیر خود تماس بگیرید.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "احراز هویت دو مرحله‌ای اجباری است اما در حساب شما پیکربندی نشده است. برای راهنمایی با مدیر خود تماس بگیرید.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "احراز هویت دو مرحله‌ای اجباری است اما در حساب شما پیکربندی نشده است. لطفاً به راه‌اندازی احراز هویت دو مرحله‌ای ادامه دهید.",
    "Set up two-factor authentication" : "تنظیم احراز هویت دو مرحله‌ای",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "احراز هویت دو مرحله‌ای اجباری است اما در حساب شما پیکربندی نشده است. برای ورود از یکی از کدهای پشتیبان خود استفاده کنید یا برای راهنمایی با مدیر خود تماس بگیرید.",
    "Use backup code" : "از کد پشتیبان استفاده شود",
    "Cancel login" : "لغو ورود",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "امنیت پیشرفته برای حساب شما اجباری است. ارائه‌دهنده را برای راه‌اندازی انتخاب کنید:",
    "Error while validating your second factor" : "خطا در اعتبار سنجی عامل دوم شما",
    "Access through untrusted domain" : "دسترسی از طریق دامنه نامعتبر",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "لطفاً با مدیر خود تماس بگیرید. اگر شما مدیر هستید، تنظیمات \"trusted_domains\" را در config/config.php مانند مثال در config.sample.php ویرایش کنید.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "اطلاعات بیشتر در مورد نحوه پیکربندی این مورد را می توانید در %1$sمستندات%2$s بیابید.",
    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
    "%1$s will be updated to version %2$s" : "%1$s به نسخه %2$s بروزرسانی خواهد شد",
    "The following apps will be updated:" : "برنامه‌های زیر بروزرسانی خواهند شد:",
    "These incompatible apps will be disabled:" : "این برنامه‌های ناسازگار غیر فعال می‌شوند:",
    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "لطفاً قبل از ادامه کار از پایگاه داده، پوشه پیکربندی و پوشه داده‌ها نسخه پشتیبان تهیه کنید.",
    "Start update" : "اغاز به روز رسانی",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "برای جلوگیری از وقفه در نصب های طولانی تر، شما می توانید دستورات زیر را از مسیر نصبتان اجرا کنید:",
    "Detailed logs" : "Detailed logs",
    "Update needed" : "نیاز به روز رسانی دارد",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "لطفاً از به‌روزرسان خط فرمان استفاده کنید زیرا شما یک نمونه بزرگ با بیش از ۵۰ حساب دارید.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "من می‌دانم که اگر به‌روزرسانی را از طریق رابط کاربری وب ادامه دهم، این خطر وجود دارد که درخواست به دلیل انقضای زمان متوقف شده و منجر به از دست رفتن داده‌ها شود، اما من پشتیبان دارم و می‌دانم چگونه در صورت بروز مشکل، نمونه خود را بازیابی کنم.",
    "Upgrade via web on my own risk" : "ارتقا از طریق وب با مسئولیت خودم",
    "Maintenance mode" : "حالت نگهداری",
    "This %s instance is currently in maintenance mode, which may take a while." : "این نمونه %s در حال حاضر در حالت نگهداری است که ممکن است مدتی طول بکشد.",
    "This page will refresh itself when the instance is available again." : "این صفحه پس از در دسترس قرار گرفتن مجدد نمونه، خود را بازخوانی خواهد کرد.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "اگر این پیغام همچنان وجود داشت یا به صورت غیر منتظره ظاهر شد با مدیر سیستم تماس بگیرید.",
    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
    "No crop data provided" : "هیچ داده برش داده شده ارائه نشده است",
    "No valid crop data provided" : "هیچ داده برش داده شده معتبر ارائه نشده است",
    "Crop is not square" : "بخش بریده شده مربع نیست",
    "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
    "For more details see the {linkstart}documentation ↗{linkend}." : "برای جزئیات بیشتر به {linkstart}مستندات ↗{linkend} مراجعه کنید.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "چت، تماس‌های ویدیویی، اشتراک‌گذاری صفحه، جلسات آنلاین و کنفرانس وب – در مرورگر شما و با برنامه‌های موبایل.",
    "You have not added any info yet" : "شما هنوز هیچ اطلاعاتی اضافه نکرده اید",
    "{user} has not added any info yet" : "{user} هنوز هیچ اطلاعاتی اضافه نکرده است",
    "Error opening the user status modal, try hard refreshing the page" : "خطا در باز کردن مودال وضعیت کاربر، سعی کنید صفحه را به شدت تازه‌سازی کنید",
    "Edit Profile" : "ویرایش نمایه",
    "The headline and about sections will show up here" : "بخش‌های سربرگ و درباره در اینجا نمایش داده خواهند شد",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
    "Restricted" : "محدود شده",
    "Invisible" : "غیر قابل مشاهده",
    "Delete" : "حذف",
    "Rename" : "تغییرنام",
    "Collaborative tags" : "برچسب های همکاری",
    "No tags found" : "هیچ برچسبی یافت نشد",
    "Profile not found" : "نمایه، یافت نشد",
    "The profile does not exist." : "این نمایه وجود ندارد.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "برای اطلاعات در مورد نحوه پیکربندی صحیح سرور خود، لطفاً <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">مستندات</a> را مشاهده کنید.",
    "<strong>Create an admin account</strong>" : "<strong>ایجاد یک حساب کاربری مدیر</strong>",
    "New admin account name" : "نام حساب کاربری مدیر جدید",
    "New admin password" : "گذرواژه مدیر جدید",
    "Show password" : "نمایش گذرواژه",
    "Toggle password visibility" : "تغییر دید گذرواژه",
    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
    "Only %s is available." : "تنها %s موجود است.",
    "Database account" : "حساب پایگاه داده",
    "Direct link copied to clipboard" : "لینک مستقیم در کلیپ‌بورد کپی شد."
},
"nplurals=2; plural=(n > 1);");
